package com.inspect.metadata.montdata.mapper;

import com.inspect.metadata.montdata.domain.BasedataMontTaskResult;
import org.apache.ibatis.annotations.Mapper;

import java.util.Date;
import java.util.List;

@Mapper
public interface BasedataMontTaskResultMapper {
    BasedataMontTaskResult selectBasedataMontTaskResultByTaskResultId(Long taskResultId);

    List<BasedataMontTaskResult> selectBasedataMontTaskResultList(BasedataMontTaskResult taskResult);

    int insertBasedataMontTaskResult(BasedataMontTaskResult taskResult);

    int updateBasedataMontTaskResult(BasedataMontTaskResult taskResult);

    int deleteBasedataMontTaskResultByTaskResultId(Long taskResultId);

    int deleteBasedataMontTaskResultByTaskResultIds(Long[] taskResultIds);

    Integer countTimesByPatrolDeviceCode(String patrolDeviceCode);

    Date selectMinCreateTimeByPatrolDeviceCode(String patrolDeviceCode);
}
